pub trait StepForward {
// Required method
fn step_forward(&self) -> Self;
}Expand description
Advance a timestamp by the least amount possible such that
ts.less_than(ts.step_forward()) is true.
TODO: Unify this with repr’s TimestampManipulation. Or, ideally, get rid of
it entirely by making txn-wal methods take an advance_to argument.
Required Methods
Sourcefn step_forward(&self) -> Self
fn step_forward(&self) -> Self
Advance a timestamp by the least amount possible such that
ts.less_than(ts.step_forward()) is true. Panic if unable to do so.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".